about summary refs log tree commit diff
diff options
context:
space:
mode:
authorEmily <vcs@emily.moe>2024-09-28 15:57:32 +0100
committerGitHub <noreply@github.com>2024-09-28 15:57:32 +0100
commit818089ba7383b6a8950a8b74d12744850cd46652 (patch)
tree28f321af8d177779c7a2304923d5d81a2395df25
parent813868bc4752f5d07c1573aec3998d05c4ec08ac (diff)
parentdc7db9bcc41b7422c178b9d2c8e49b60e65c933b (diff)
teams: create the Xen Project Team and rename instances of `Xen` to `Xen Project`. (#344314)
-rw-r--r--maintainers/maintainer-list.nix12
-rw-r--r--maintainers/team-list.nix13
-rw-r--r--nixos/doc/manual/release-notes/rl-2411.section.md6
-rw-r--r--nixos/modules/virtualisation/xe-guest-utilities.nix2
-rwxr-xr-xnixos/modules/virtualisation/xen-boot-builder.sh4
-rw-r--r--nixos/modules/virtualisation/xen-dom0.nix10
-rw-r--r--pkgs/applications/virtualization/xen/README.md6
-rw-r--r--pkgs/applications/virtualization/xen/generic/default.nix20
-rw-r--r--pkgs/applications/virtualization/xen/packages.nix22
-rw-r--r--pkgs/by-name/xe/xen-guest-agent/package.nix6
-rw-r--r--pkgs/by-name/xt/xtf/package.nix2
-rw-r--r--pkgs/development/ocaml-modules/vchan/default.nix2
-rw-r--r--pkgs/development/ocaml-modules/xenstore/default.nix5
-rw-r--r--pkgs/development/ocaml-modules/xenstore_transport/default.nix1
14 files changed, 65 insertions, 46 deletions
diff --git a/maintainers/maintainer-list.nix b/maintainers/maintainer-list.nix
index 4b2d51599a2cc..fd20bc373856f 100644
--- a/maintainers/maintainer-list.nix
+++ b/maintainers/maintainer-list.nix
@@ -8363,6 +8363,12 @@
     githubId = 287769;
     name = "Sergii Paryzhskyi";
   };
+  hehongbo = {
+    name = "Hongbo";
+    github = "hehongbo";
+    githubId = 665472;
+    matrix = "@hehongbo:matrix.org";
+  };
   heijligen = {
     email = "src@posteo.de";
     github = "heijligen";
@@ -17485,6 +17491,12 @@
     githubId = 5653911;
     name = "Rampoina";
   };
+  rane = {
+    email = "rane+nix@junkyard.systems";
+    github = "digitalrane";
+    githubId = 1829286;
+    name = "Rane";
+  };
   ranfdev = {
     email = "ranfdev@gmail.com";
     name = "Lorenzo Miglietta";
diff --git a/maintainers/team-list.nix b/maintainers/team-list.nix
index e75a2850f2dcf..546c944e0c53f 100644
--- a/maintainers/team-list.nix
+++ b/maintainers/team-list.nix
@@ -1022,6 +1022,19 @@ with lib.maintainers;
     shortName = "WDZ GmbH";
   };
 
+  xen = {
+    members = [
+      hehongbo
+      lach
+      rane
+      sigmasquadron
+    ];
+    scope = "Maintain the Xen Project Hypervisor and the related tooling ecosystem.";
+    shortName = "Xen Project Hypervisor";
+    enableFeatureFreezePing = true;
+    githubTeams = [ "xen-project" ];
+  };
+
   xfce = {
     members = [
       bobby285271
diff --git a/nixos/doc/manual/release-notes/rl-2411.section.md b/nixos/doc/manual/release-notes/rl-2411.section.md
index f9a5846c1f384..23143a4fb0270 100644
--- a/nixos/doc/manual/release-notes/rl-2411.section.md
+++ b/nixos/doc/manual/release-notes/rl-2411.section.md
@@ -49,13 +49,13 @@
 - Support for mounting filesystems from block devices protected with [dm-verity](https://docs.kernel.org/admin-guide/device-mapper/verity.html)
   was added through the `boot.initrd.systemd.dmVerity` option.
 
-- The [Xen Hypervisor](https://xenproject.org) is once again available as a virtualisation option under [`virtualisation.xen`](#opt-virtualisation.xen.enable).
+- The [Xen Project Hypervisor](https://xenproject.org) is once again available as a virtualisation option under [`virtualisation.xen`](#opt-virtualisation.xen.enable).
   - This release includes Xen [4.17.5](https://wiki.xenproject.org/wiki/Xen_Project_4.17_Release_Notes), [4.18.3](https://wiki.xenproject.org/wiki/Xen_Project_4.18_Release_Notes) and [4.19.0](https://wiki.xenproject.org/wiki/Xen_Project_4.19_Release_Notes), as well as support for booting the hypervisor on EFI systems.
   ::: {.warning}
-    Booting into Xen through a legacy BIOS bootloader or with the legacy script-based Stage 1 initrd have been **deprecated**. Only EFI booting and the new systemd-based Stage 1 initrd are supported.
+    Booting into the Xen Project Hypervisor through a legacy BIOS bootloader or with the legacy script-based Stage 1 initrd have been **deprecated**. Only EFI booting and the new systemd-based Stage 1 initrd are supported.
   :::
   - There are two flavours of Xen available by default: `xen`, which includes all built-in components, and `xen-slim`, which replaces the built-in components with their Nixpkgs equivalents.
-    - The `qemu-xen-traditional` component has been deprecated by upstream Xen, and is no longer available in any of the Xen packages.
+    - The `qemu-xen-traditional` component has been deprecated by the upstream Xen Project, and is no longer available in any of the Xen Project Hypervisor packages.
   - The OCaml-based Xen Store can now be configured using  [`virtualisation.xen.store.settings`](#opt-virtualisation.xen.store.settings).
   - The `virtualisation.xen.bridge` options have been deprecated in this release cycle. Users who need network bridges are encouraged to set up their own networking configurations.
 
diff --git a/nixos/modules/virtualisation/xe-guest-utilities.nix b/nixos/modules/virtualisation/xe-guest-utilities.nix
index 9bc68c0a3d7d6..14dd25e878cf1 100644
--- a/nixos/modules/virtualisation/xe-guest-utilities.nix
+++ b/nixos/modules/virtualisation/xe-guest-utilities.nix
@@ -4,7 +4,7 @@ let
 in {
   options = {
     services.xe-guest-utilities = {
-      enable = lib.mkEnableOption "the Xen guest utilities daemon";
+      enable = lib.mkEnableOption "the XenServer guest utilities daemon";
     };
   };
   config = lib.mkIf cfg.enable {
diff --git a/nixos/modules/virtualisation/xen-boot-builder.sh b/nixos/modules/virtualisation/xen-boot-builder.sh
index 13e1a4e202432..1b7c1470f6eb4 100755
--- a/nixos/modules/virtualisation/xen-boot-builder.sh
+++ b/nixos/modules/virtualisation/xen-boot-builder.sh
@@ -5,7 +5,7 @@
 [[ $# -ne 1 ]] && echo -e "\e[1;31merror:\e[0m xenBootBuilder must be called with exactly one verbosity argument. See the \e[1;34mvirtualisation.xen.efi.bootBuilderVerbosity\e[0m option." && exit 1
 case "$1" in
     "quiet") true ;;
-    "default" | "info") echo -n "Installing Xen Hypervisor boot entries..." ;;
+    "default" | "info") echo -n "Installing Xen Project Hypervisor boot entries..." ;;
     "debug") echo -e "\e[1;34mxenBootBuilder:\e[0m called with the '$1' flag" ;;
     *)
         echo -e "\e[1;31merror:\e[0m xenBootBuilder was called with an invalid argument. See the \e[1;34mvirtualisation.xen.efi.bootBuilderVerbosity\e[0m option."
@@ -150,7 +150,7 @@ else
     esac
     if [ "$1" = "info" ]; then
         if [[ ${#preGenerations[@]} == "${#postGenerations[@]}" ]]; then
-            echo -e "\e[1;33mNo Change:\e[0m Xen Hypervisor boot entries were refreshed, but their contents are identical."
+            echo -e "\e[1;33mNo Change:\e[0m Xen Project Hypervisor boot entries were refreshed, but their contents are identical."
         else
             echo -e "\e[1;32mSuccess:\e[0m Changed the following boot entries:"
             # We briefly unset errexit and pipefail here, as GNU diff has no option to not fail when files differ.
diff --git a/pkgs/applications/virtualization/xen/README.md b/pkgs/applications/virtualization/xen/README.md
index 02d1ab7227073..07087e2fee230 100644
--- a/pkgs/applications/virtualization/xen/README.md
+++ b/pkgs/applications/virtualization/xen/README.md
@@ -15,11 +15,11 @@
   </a>
 </p>
 
-# Xen Hypervisor <a href="https://xenproject.org/"><img src="https://downloads.xenproject.org/Branding/Mascots/Xen-Fu-Panda-2000px.png" width="48px" align="top" alt="Xen Fu Panda"></a>
+# Xen Project Hypervisor <a href="https://xenproject.org/"><img src="https://downloads.xenproject.org/Branding/Mascots/Xen-Fu-Panda-2000px.png" width="48px" align="top" alt="Xen Fu Panda"></a>
 
-This directory includes the build recipes for the [Xen Hypervisor](https://xenproject.org/).
+This directory includes the build recipes for the [Xen Project Hypervisor](https://xenproject.org/).
 
-Some other notable packages that compose the Xen Ecosystem include:
+Some other notable packages that compose the Xen Project Ecosystem include:
 
 - `ocamlPackages.xenstore`: Mirage's `oxenstore` implementation.
 - `ocamlPackages.vchan`: Mirage's `xen-vchan` implementation.
diff --git a/pkgs/applications/virtualization/xen/generic/default.nix b/pkgs/applications/virtualization/xen/generic/default.nix
index fbbefa95d61d4..250e5a41bfc1f 100644
--- a/pkgs/applications/virtualization/xen/generic/default.nix
+++ b/pkgs/applications/virtualization/xen/generic/default.nix
@@ -647,7 +647,7 @@ stdenv.mkDerivation (finalAttrs: {
 
         # Short description for Xen.
         description =
-          "Xen Hypervisor"
+          "Xen Project Hypervisor"
           # The "and related components" addition is automatically hidden if said components aren't being built.
           + lib.strings.optionalString (prefetchedSources != { }) " and related components"
           # To alter the description inside the paranthesis, edit ./packages.nix.
@@ -681,18 +681,18 @@ stdenv.mkDerivation (finalAttrs: {
                 # Originally, this was a call for the complicated withPrefetchedSources. Since there aren't
                 # that many optional components, we just use lib.strings.optionalString, because it's simpler.
                 # Optional components that aren't being built are automatically hidden.
-                + lib.strings.optionalString withEFI "\n* `xen.efi`: Xen's [EFI binary](https://xenbits.xenproject.org/docs/${branch}-testing/misc/efi.html), available on the `boot` output of this package."
+                + lib.strings.optionalString withEFI "\n* `xen.efi`: The Xen Project's [EFI binary](https://xenbits.xenproject.org/docs/${branch}-testing/misc/efi.html), available on the `boot` output of this package."
                 + lib.strings.optionalString withFlask "\n* `xsm-flask`: The [FLASK Xen Security Module](https://wiki.xenproject.org/wiki/Xen_Security_Modules_:_XSM-FLASK). The `xenpolicy-${version}` file is available on the `boot` output of this package."
-                + lib.strings.optionalString withInternalQEMU "\n* `qemu-xen`: Xen's mirror of [QEMU](https://www.qemu.org/)."
-                + lib.strings.optionalString withInternalSeaBIOS "\n* `seabios-xen`: Xen's mirror of [SeaBIOS](https://www.seabios.org/SeaBIOS)."
-                + lib.strings.optionalString withInternalOVMF "\n* `ovmf-xen`: Xen's mirror of [OVMF](https://github.com/tianocore/tianocore.github.io/wiki/OVMF)."
-                + lib.strings.optionalString withInternalIPXE "\n* `ipxe-xen`: Xen's pinned version of [iPXE](https://ipxe.org/)."
+                + lib.strings.optionalString withInternalQEMU "\n* `qemu-xen`: The Xen Project's mirror of [QEMU](https://www.qemu.org/)."
+                + lib.strings.optionalString withInternalSeaBIOS "\n* `seabios-xen`: The Xen Project's mirror of [SeaBIOS](https://www.seabios.org/SeaBIOS)."
+                + lib.strings.optionalString withInternalOVMF "\n* `ovmf-xen`: The Xen Project's mirror of [OVMF](https://github.com/tianocore/tianocore.github.io/wiki/OVMF)."
+                + lib.strings.optionalString withInternalIPXE "\n* `ipxe-xen`: The Xen Project's pinned version of [iPXE](https://ipxe.org/)."
               )
           # Finally, we write a notice explaining which vulnerabilities this Xen is NOT vulnerable to.
           # This will hopefully give users the peace of mind that their Xen is secure, without needing
           # to search the source code for the XSA patches.
           + lib.strings.optionalString (writeAdvisoryDescription != [ ]) (
-            "\n\nThis Xen (${version}) has been patched against the following known security vulnerabilities:\n"
+            "\n\nThis Xen Project Hypervisor (${version}) has been patched against the following known security vulnerabilities:\n"
             + lib.strings.removeSuffix "\n" (lib.strings.concatLines writeAdvisoryDescription)
           );
 
@@ -712,10 +712,8 @@ stdenv.mkDerivation (finalAttrs: {
         ];
 
         # This automatically removes maintainers from EOL versions of Xen, so we aren't bothered about versions we don't explictly support.
-        maintainers = lib.lists.optionals (lib.strings.versionAtLeast version minSupportedVersion) (
-          with lib.maintainers; [ sigmasquadron ]
-        );
-        knownVulnerabilities = lib.lists.optional (lib.strings.versionOlder version minSupportedVersion) "Xen ${version} is no longer supported by the Xen Security Team. See https://xenbits.xenproject.org/docs/unstable/support-matrix.html";
+        maintainers = lib.lists.optionals (lib.strings.versionAtLeast version minSupportedVersion) lib.teams.xen.members;
+        knownVulnerabilities = lib.lists.optional (lib.strings.versionOlder version minSupportedVersion) "The Xen Project Hypervisor version ${version} is no longer supported by the Xen Project Security Team. See https://xenbits.xenproject.org/docs/unstable/support-matrix.html";
 
         mainProgram = "xl";
 
diff --git a/pkgs/applications/virtualization/xen/packages.nix b/pkgs/applications/virtualization/xen/packages.nix
index 77c9cbf099a3c..7402edc8bc70f 100644
--- a/pkgs/applications/virtualization/xen/packages.nix
+++ b/pkgs/applications/virtualization/xen/packages.nix
@@ -2,13 +2,13 @@
 let
   standard = {
     meta = {
-      description = "Standard Xen";
+      description = "Standard";
       longDescription = ''
-        Standard version of Xen. Uses forks of QEMU, SeaBIOS, OVMF and iPXE provided
-        by the Xen Project. This provides the vanilla Xen experince, but wastes space
-        and build time. A typical NixOS setup that runs lots of VMs will usually need
-        to build two different versions of QEMU when using this Xen derivation (one
-        fork and upstream).
+        Standard version of the Xen Project Hypervisor. Uses forks of QEMU, SeaBIOS,
+        OVMF and iPXE provided by the Xen Project. This provides the vanilla Xen
+        experience, but wastes space and build time. A typical NixOS setup that runs
+        lots of VMs will usually need to build two different versions of QEMU when using
+        this Xen derivation (one fork and upstream).
       '';
     };
   };
@@ -16,11 +16,11 @@ let
     meta = {
       description = "Without Internal Components";
       longDescription = ''
-        Slimmed-down version of Xen that reuses nixpkgs packages as much as possible.
-        Instead of using the Xen forks for various internal components, this version uses
-        `seabios`, `ovmf` and `ipxe` from nixpkgs. These components may ocasionally get
-        out of sync with the hypervisor itself, but this builds faster and uses less space
-        than the default derivation.
+        Slimmed-down version of the Xen Project Hypervisor that reuses nixpkgs packages
+        as much as possible. Instead of using the Xen Project forks for various internal
+        components, this version uses `seabios`, `ovmf` and `ipxe` from Nixpkgs. These
+        components may ocasionally get out of sync with the hypervisor itself, but this
+        builds faster and uses less space than the default derivation.
       '';
     };
   };
diff --git a/pkgs/by-name/xe/xen-guest-agent/package.nix b/pkgs/by-name/xe/xen-guest-agent/package.nix
index 9375b0d476560..b0223a6311ed2 100644
--- a/pkgs/by-name/xe/xen-guest-agent/package.nix
+++ b/pkgs/by-name/xe/xen-guest-agent/package.nix
@@ -45,9 +45,7 @@ rustPlatform.buildRustPackage rec {
     homepage = "https://gitlab.com/xen-project/xen-guest-agent";
     license = lib.licenses.agpl3Only;
     platforms = lib.platforms.unix;
-    maintainers = with lib.maintainers; [
-      matdibu
-      sigmasquadron
-    ];
+    maintainers = lib.teams.xen.members;
+    mainProgram = "xen-guest-agent";
   };
 }
diff --git a/pkgs/by-name/xt/xtf/package.nix b/pkgs/by-name/xt/xtf/package.nix
index 4a19f84c89ecf..acf98626b1abd 100644
--- a/pkgs/by-name/xt/xtf/package.nix
+++ b/pkgs/by-name/xt/xtf/package.nix
@@ -71,7 +71,7 @@ stdenv.mkDerivation {
     description = "Xen Test Framework and Suite for creating microkernel-based tests";
     homepage = "https://xenbits.xenproject.org/docs/xtf/index.html";
     license = lib.licenses.bsd2;
-    maintainers = with lib.maintainers; [ sigmasquadron ];
+    maintainers = lib.teams.xen.members;
     mainProgram = "xtf-runner";
     platforms = lib.lists.intersectLists lib.platforms.linux lib.platforms.x86_64;
   };
diff --git a/pkgs/development/ocaml-modules/vchan/default.nix b/pkgs/development/ocaml-modules/vchan/default.nix
index e1be60da8bd7e..51aae9b59b345 100644
--- a/pkgs/development/ocaml-modules/vchan/default.nix
+++ b/pkgs/development/ocaml-modules/vchan/default.nix
@@ -32,6 +32,6 @@ buildDunePackage rec {
     description = "Xen Vchan implementation";
     homepage = "https://github.com/mirage/ocaml-vchan";
     license = licenses.isc;
-    maintainers = [ maintainers.sternenseemann ];
+    maintainers = teams.xen.members ++ [ maintainers.sternenseemann ];
   };
 }
diff --git a/pkgs/development/ocaml-modules/xenstore/default.nix b/pkgs/development/ocaml-modules/xenstore/default.nix
index 296597a6a6292..2955755ccb41c 100644
--- a/pkgs/development/ocaml-modules/xenstore/default.nix
+++ b/pkgs/development/ocaml-modules/xenstore/default.nix
@@ -25,10 +25,7 @@ buildDunePackage rec {
   meta = with lib; {
     description = "Xenstore protocol in pure OCaml";
     license = licenses.lgpl21Only;
-    maintainers = with maintainers; [
-      sternenseemann
-      sigmasquadron
-    ];
+    maintainers = teams.xen.members ++ [ maintainers.sternenseemann ];
     homepage = "https://github.com/mirage/ocaml-xenstore";
   };
 }
diff --git a/pkgs/development/ocaml-modules/xenstore_transport/default.nix b/pkgs/development/ocaml-modules/xenstore_transport/default.nix
index f0867b4ec314e..5ef03349e68a8 100644
--- a/pkgs/development/ocaml-modules/xenstore_transport/default.nix
+++ b/pkgs/development/ocaml-modules/xenstore_transport/default.nix
@@ -23,5 +23,6 @@ buildDunePackage rec {
     description = "Low-level libraries for connecting to a xenstore service on a xen host";
     license = licenses.lgpl21Only;
     homepage = "https://github.com/xapi-project/ocaml-xenstore-clients";
+    maintainers = teams.xen.members;
   };
 }
diff --git a/nixos/modules/virtualisation/xen-dom0.nix b/nixos/modules/virtualisation/xen-dom0.nix
index 2cc82c9101109..9b6ec543dae59 100644
--- a/nixos/modules/virtualisation/xen-dom0.nix
+++ b/nixos/modules/virtualisation/xen-dom0.nix
@@ -1,4 +1,4 @@
 # Xen hypervisor (Dom0) support.
 
 {
   config,
@@ -123,7 +123,7 @@ in
 
   options.virtualisation.xen = {
 
-    enable = lib.options.mkEnableOption "the Xen Hypervisor, a virtualisation technology defined as a *type-1 hypervisor*, which allows multiple virtual machines, known as *domains*, to run concurrently on the physical machine. NixOS runs as the privileged *Domain 0*. This option requires a reboot into a Xen kernel to take effect";
+    enable = lib.options.mkEnableOption "the Xen Project Hypervisor, a virtualisation technology defined as a *type-1 hypervisor*, which allows multiple virtual machines, known as *domains*, to run concurrently on the physical machine. NixOS runs as the privileged *Domain 0*. This option requires a reboot into a Xen kernel to take effect";
 
     debug = lib.options.mkEnableOption "Xen debug features for Domain 0. This option enables some hidden debugging tests and features, and should not be used in production";
 
@@ -141,7 +141,7 @@ in
       defaultText = lib.options.literalExpression "pkgs.xen";
       example = lib.options.literalExpression "pkgs.xen-slim";
       description = ''
-        The package used for Xen Hypervisor.
+        The package used for Xen Project Hypervisor.
       '';
       relatedPackages = [
         "xen"
@@ -207,7 +207,7 @@ in
 
           - `quiet` supresses all messages.
 
-          - `default` adds a simple "Installing Xen Hypervisor boot entries...done." message to the script.
+          - `default` adds a simple "Installing Xen Project Hypervisor boot entries...done." message to the script.
 
           - `info` is the same as `default`, but it also prints a diff with information on which generations were altered.
             - This option adds two extra dependencies to the script: `diffutils` and `bat`.
@@ -870,5 +870,5 @@ in
       };
     };
   };
-  meta.maintainers = with lib.maintainers; [ sigmasquadron ];
+  meta.maintainers = lib.teams.xen.members;
 }
@@ -1,4 +1,4 @@
-# Xen hypervisor (Dom0) support.
+# Xen Project Hypervisor (Dom0) support.
 
 {